
## CATO-CLI - query.site.siteGeneralDetails:
[Click here](https://api.catonetworks.com/documentation/#query-query.site.siteGeneralDetails) for documentation on this operation.

### Usage for query.site.siteGeneralDetails:

`catocli query site siteGeneralDetails -h`

`catocli query site siteGeneralDetails <json>`

`catocli query site siteGeneralDetails "$(cat < query.site.siteGeneralDetails.json)"`

`catocli query site siteGeneralDetails '{"siteRefInput":{"by":"ID","input":"string"}}'`


#### Operation Arguments for query.site.siteGeneralDetails ####

`accountId` [ID] - (required) N/A    
`siteRefInput` [SiteRefInput] - (required) N/A    
